@@ -8,9 +8,20 @@
 
 #include "device.h"
 
+#include <QHash>
 #include <QObject>
+#include <QDateTime>
+#include <QTimer>
 
 class AbstractSystem;
+class KStatusNotifierItem;
+class QAction;
+class RemoteControllersSettings;
+
+namespace TaskManager
+{
+    class TasksModel;
+}
 
 class ControllerManager : public QObject
 {
@@ -30,17 +41,27 @@ public:
     void noopInput();
 
 public slots:
-    void emitKey(int key, bool pressed) const;
+    void emitKey(int key, bool pressed);
     void removeDevice(int deviceIndex);
     QVector<Device*> connectedDevices();
+    void refreshApps();
 
 Q_SIGNALS:
     void deviceConnected(Device*);
     void deviceDisconnected(Device*);
 
 private:
-    QStringList m_applicationInhibit;
+    void simulateUserActivity();
+    bool appInhibited(const QString &appId) const;
+
     bool m_enabled = true;
     QVector<Device*> m_connectedDevices;
     QScopedPointer<AbstractSystem> m_inputSystem;
+    KStatusNotifierItem *m_sni = nullptr;
+    TaskManager::TasksModel *m_appsModel = nullptr;
+    QHash<QString, QAction *> m_appActions;
+    QScopedPointer<RemoteControllersSettings> m_settings;
+    QTimer m_lastUsed;
+
+    QDateTime m_lastSimulated;
 };
